@@ -12,7 +12,7 @@ cd ${test_wd}
 
 # Test doing a replace
 
-odc mdset "expver='    0001'" ../2000010106.odb temporary1.odb
+odc mdset "expver='    0001'" ../../tests/2000010106-reduced.odb temporary1.odb
 
 # And go back to where we were
 
@@ -20,9 +20,9 @@ odc mdset "expver='0018    '" temporary1.odb temporary2.odb
 
 # And check that we made a change, and reverted it
 
-odc compare ../2000010106.odb temporary2.odb
+odc compare ../../tests/2000010106-reduced.odb temporary2.odb
 
-odc compare ../2000010106.odb temporary1.odb && exit -1
+odc compare ../../tests/2000010106-reduced.odb temporary1.odb && exit -1
 
 # Clean up
 
